@@ -24,23 +24,6 @@ def _format_ecr_uri(uri):
     }
 
 
-def _summarise_release_deployments(releases):
-    for release in releases:
-        for deployment in release['deployments']:
-            try:
-                requested_by = deployment.get("requested_by", {}).get("id", "")
-            except AttributeError:
-                requested_by = deployment.get("requested_by", "")
-
-            yield {
-                'release_id': release.get('release_id'),
-                'environment_id': deployment.get('environment'),
-                'deployed_date': parse(deployment.get('date_created')),
-                'requested_by': requested_by.split('/')[-1],
-                'description': deployment.get('description')
-            }
-
-
 @click.group()
 @click.option('--project-file', '-f', default=DEFAULT_PROJECT_FILEPATH)
 @click.option('--verbose', '-v', is_flag=True, help="Print verbose messages.")
@@ -150,9 +133,7 @@ def publish(ctx, image_id, label):
     )
 
 
-def _deploy(project, release_id, environment_id, description, confirm=True):
-    release = project.get_release(release_id)
-
+def _deploy(project, release, environment_id, description, confirm=True):
     environment = project.get_environment(environment_id)
     env_id = environment.get('id')
     env_name = environment.get('name', environment_id)
@@ -187,7 +168,7 @@ def _deploy(project, release_id, environment_id, description, confirm=True):
         click.echo("")
         click.confirm(click.style("Create deployment?", fg="cyan", bold=True), abort=True)
 
-    result = project.deploy(release_id, environment_id, description)
+    result = project.deploy(release["release_id"], environment_id, description)
 
     # Save the result of the deployment, including things like the ECS deploy IDs.
     # These can be useful for debugging if something goes wrong.
@@ -253,9 +234,11 @@ def deploy(ctx, release_id, environment_id, description):
     confirm = ctx.obj['confirm']
     project = ctx.obj['project']
 
+    release = project.get_release(release_id)
+
     _deploy(
         project=project,
-        release_id=release_id,
+        release=release,
         environment_id=environment_id,
         description=description,
         confirm=confirm
@@ -387,7 +370,7 @@ def release_deploy(ctx, from_label, environment_id, description):
     project = ctx.obj['project']
     confirm = ctx.obj['confirm']
 
-    release_id = _prepare(
+    release = _prepare(
         project=project,
         from_label=from_label,
         description=description
@@ -395,7 +378,7 @@ def release_deploy(ctx, from_label, environment_id, description):
 
     _deploy(
         project=project,
-        release_id=release_id,
+        release=release,
         environment_id=environment_id,
         description=description,
         confirm=confirm
@@ -422,8 +405,6 @@ def show_release(ctx, release_id):
 def show_deployments(ctx, release_id):
     project = ctx.obj['project']
 
-    releases = project.get_deployments(release_id)
-
     rows = []
 
     headers = [
@@ -434,19 +415,18 @@ def show_deployments(ctx, release_id):
         "description"
     ]
 
-    for summary in _summarise_release_deployments(releases):
-        try:
-            environment_id = summary["environment_id"].get("id", "")
-        except AttributeError:
-            environment_id = summary["environment_id"]
-
-        rows.append([
-            summary["release_id"],
-            environment_id,
-            pprint_date(summary["deployed_date"]),
-            summary["requested_by"],
-            summary["description"]
-        ])
+    for deployment in project.get_deployments(release_id=release_id):
+        rows.append(
+            [
+                deployment["release_id"],
+                deployment["environment"],
+                pprint_date(parse(deployment["date_created"])),
+                deployment["requested_by"].split("/")[-1],
+                deployment["description"]
+                if deployment["description"] != "No description provided"
+                else "-",
+            ]
+        )
 
     print(tabulate(rows, headers=headers))
 
